==> melvin-0.1.1.tar.gz: melvin-0.1.1/README.pypi.md <==
![logo](https://s3.us-west-2.amazonaws.com/tecton.ai.public/documentation/pypi/tecton-logo.svg)

Tecton is the fastest way to build operational AI applications.

# Melvin - Tecton Copilot

Melvin is Tecton's AI-powered copilot for feature engineering and feature store operations. It is currently in private preview.

With Melvin, you can:
- Get assistance with feature engineering tasks
- Explore your feature store using natural language
- Generate feature definitions and transformations
- Debug and optimize your feature pipelines
- Leverage LLM transformations and feature extraction in Batch, Streaming, and Realtime

# Installation

```bash
pip install melvin
```

# Usage

After installation, you can start Melvin with:

```bash
melvin --port 3000
```

Options:
- `--port`: Specify the port (default: 3000)
- `--host`: Specify the host (default: localhost)
- `--browser`: Open the browser automatically

# License

Copyright (2023) Tecton, Inc. This library (the "Software") may not be used except in connection with the Licensee's use
of the Tecton Platform Services (defined below) pursuant to an Agreement (defined below) between Licensee (defined
below) and Tecton, Inc. ("Tecton"). This Software shall be deemed part of the "Services" under the Agreement, or if the
Agreement does not define Services, then the term in such Agreement that refers to the applicable Tecton Platform
Services (as defined below) shall be substituted herein for "Services." Licensee's use of the Software must comply at
all times with any restrictions applicable to the Services, generally, and must be used in accordance with any
applicable documentation. If you have not agreed to an Agreement or otherwise do not agree to these terms, you may not
use the Software. This license terminates automatically upon the termination of the Agreement or Licensee's breach of
these terms. Agreement: the agreement between Tecton and Licensee governing the use of the Tecton Platform Services,
which shall be, with respect to Tecton, the Tecton Platform-as-a-Service Agreement located
at https://www.tecton.ai/tecton_online-tos/, unless Licensee has entered into a separate written agreement with Tecton
governing the use of the Tecton Platform Services. Tecton Platform Services: the Tecton services according to where the
Software is used. Licensee: the user of the Software, or, if the Software is being used on behalf of a company, the
company.

==> melvin-0.1.3.tar.gz: melvin-0.1.3/README.pypi.md <==
![logo](https://s3.us-west-2.amazonaws.com/tecton.ai.public/documentation/pypi/tecton-logo.svg)

Tecton is the fastest way to build operational AI applications.

# Melvin - Tecton Copilot

Melvin is Tecton's AI-powered copilot for feature engineering and feature store operations. It is currently in private preview.

With Melvin, you can:
- Get assistance with feature engineering tasks
- Explore your feature store using natural language
- Generate feature definitions and transformations
- Debug and optimize your feature pipelines
- Leverage LLM transformations and feature extraction in Batch, Streaming, and Realtime

# Installation

```bash
pip install melvin
```

# Usage

After installation, you can start Melvin with:

```bash
melvin --port 3000
```

Options:
- `--port`: Specify the port (default: 3000)
- `--host`: Specify the host (default: localhost)
- `--no-browser`: Don't open the browser automatically

# License

Copyright (2023) Tecton, Inc. This library (the "Software") may not be used except in connection with the Licensee's use
of the Tecton Platform Services (defined below) pursuant to an Agreement (defined below) between Licensee (defined
below) and Tecton, Inc. ("Tecton"). This Software shall be deemed part of the "Services" under the Agreement, or if the
Agreement does not define Services, then the term in such Agreement that refers to the applicable Tecton Platform
Services (as defined below) shall be substituted herein for "Services." Licensee's use of the Software must comply at
all times with any restrictions applicable to the Services, generally, and must be used in accordance with any
applicable documentation. If you have not agreed to an Agreement or otherwise do not agree to these terms, you may not
use the Software. This license terminates automatically upon the termination of the Agreement or Licensee's breach of
these terms. Agreement: the agreement between Tecton and Licensee governing the use of the Tecton Platform Services,
which shall be, with respect to Tecton, the Tecton Platform-as-a-Service Agreement located
at https://www.tecton.ai/tecton_online-tos/, unless Licensee has entered into a separate written agreement with Tecton
governing the use of the Tecton Platform Services. Tecton Platform Services: the Tecton services according to where the
Software is used. Licensee: the user of the Software, or, if the Software is being used on behalf of a company, the
company.
